# SAP Modeling Best Practices
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-modeling-best-practices#overview)
  * [Relevant Use Cases](https://help.sap.com/docs/leanix/ea/sap-modeling-best-practices#relevant-use-cases)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/sap-modeling-best-practices#related-resources)


This modeling guide offers best practices for modeling SAP Cloud Solutions like S/4HANA and SAP BTP alongside legacy systems like SAP ERP 6.0.
